@@ -23,21 +23,21 @@ import (
 )
 
 type PrometheusUserWorkloadTask struct {
-	client             *client.Client
-	factory            *manifests.Factory
-	userWorkloadConfig *manifests.UserWorkloadConfig
+	client  *client.Client
+	factory *manifests.Factory
+	config  *manifests.Config
 }
 
-func NewPrometheusUserWorkloadTask(client *client.Client, factory *manifests.Factory, userWorkloadConfig *manifests.UserWorkloadConfig) *PrometheusUserWorkloadTask {
+func NewPrometheusUserWorkloadTask(client *client.Client, factory *manifests.Factory, config *manifests.Config) *PrometheusUserWorkloadTask {
 	return &PrometheusUserWorkloadTask{
-		client:             client,
-		factory:            factory,
-		userWorkloadConfig: userWorkloadConfig,
+		client:  client,
+		factory: factory,
+		config:  config,
 	}
 }
 
 func (t *PrometheusUserWorkloadTask) Run() error {
-	if t.userWorkloadConfig.IsEnabled() {
+	if t.config.IsUserWorkloadEnabled() {
 		return t.create()
 	}
 
@@ -139,7 +139,7 @@ func (t *PrometheusUserWorkloadTask) create() error {
 		return errors.Wrap(err, "reconciling UserWorkload Prometheus Service failed")
 	}
 
-	grpcTLS, err := t.factory.GRPCSecret(nil)
+	grpcTLS, err := t.factory.GRPCSecret()
 	if err != nil {
 		return errors.Wrap(err, "initializing UserWorkload Prometheus GRPC secret failed")
 	}
@@ -215,7 +215,7 @@ func (t *PrometheusUserWorkloadTask) destroy() error {
 		return errors.Wrap(err, "deleting UserWorkload Prometheus ServiceMonitor failed")
 	}
 
-	grpcTLS, err := t.factory.GRPCSecret(nil)
+	grpcTLS, err := t.factory.GRPCSecret()
 	if err != nil {
 		return errors.Wrap(err, "initializing UserWorkload Prometheus GRPC secret failed")
 	}
